<TS version="2.1" language="lv">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Spiediet labo peles klikšķi, lai labotu adresi vai birku</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Izveidot jaunu adresi</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Jauns</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopēt</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Aizvērt</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Izdzēst iezīmētās adreses no saraksta</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Ierakstiet meklējamo nosaukumu vai adresi</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Datus no tekošā ieliktņa eksportēt uz failu</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Eksportēt</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Dzēst</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Izvēlies adresi uz kuru sūtīt bitcoins</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Izvēlies adresi ar kuru saņemt bitcoins</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">Izvēlēties</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Šīs ir jūsu Bitcoin adreses, kuras izmantojamas maksājumu veikšanai. Vienmēr pārbaudiet summu un saņēmēja adresi pirms monētu nosūtīšanas.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Kopēt adresi</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Kopēt &amp;Marķējumu</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Rediģēt</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Eksportēt Adrešu Sarakstu</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Mēģinot saglabāt adrešu sarakstu %1 radās kļūda. Lūdzu mēģiniet vēlreiz.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Eksportēšana Neizdevās</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nosaukums</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adrese</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(bez nosaukuma)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Paroles dialogs</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Ierakstiet paroli</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Jauna parole</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Ievadiet jauno paroli vēlreiz</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Rādīt paroli</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Šifrēt maciņu</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Lai veiktu šo darbību, nepieciešama jūsu maciņa slepenā frāze maciņa atvēršanai.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Atslēgt maciņu</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Mainīt paroli</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Apstiprināt maciņa šifrēšanu</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Brīdinājums: Šifrējot Jūsu maciņu, gadījumā ja aizmirsīsiet savu paroli, Jūs NEATGRIEZENISKI ZAUDĒSIET VISUS SAVUS "BITKOINUS"!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Vai tu tiešām vēlies šifrēt savu maciņu?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Maciņš šifrēts</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Ievadiet savu paroli Jūsu maciņam, lūdzu lietojiet vismaz desmit simbolus, astoņus vai vairāk vārdus.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Ievadiet veco un jauno paroli Jūsu maciņam</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Turpināt</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Maciņu nepieciešams šifrēt.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Maciņš tagad šifrēts</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Maciņa šifrēšana neizdevās</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Ievadītās paroles nav vienādas.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Maciņa atslēgšana neizdevās</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Uzmanību! Caps Lock uz klavietūras ir ieslēgts!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Kļūda: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">nav zināms</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Daudzums</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 st</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n sekundes</numerusform>
            <numerusform>%n sekunde</numerusform>
            <numerusform>%n sekundes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minūtes</numerusform>
            <numerusform>%n minūte</numerusform>
            <numerusform>%n minūtes</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n stundas</numerusform>
            <numerusform>%n stunda</numerusform>
            <numerusform>%n stundas</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 un %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Pārskats</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Rādīt vispārēju maciņa pārskatu</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Transakcijas</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Skatīt transakciju vēsturi</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">&amp;Iziet</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Aizvērt programmu</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Par %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Rādīt informāciju par %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Par &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Parādīt informāciju par Qt</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Izveidot jaunu maciņu</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Maciņš:</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Nosūtīt bitkoinus uz Bitcoin adresi</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Izveidot maciņa rezerves kopiju citur</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Mainīt maciņa šifrēšanas paroli</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Sūtīt</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Saņemt</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Opcijas...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Šifrēt privātās atslēgas kuras pieder tavam maciņam</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Parakstīt ziņojumus ar savām Bitcoin adresēm lai pierādītu ka tās pieder tev</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Pārbaudīt ziņojumus lai pārliecinātos, ka tie tika parakstīti ar norādītajām Bitcoin adresēm</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fails</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Uzstādījumi</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Palīdzība</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Ciļņu rīkjosla</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Sinhronizē ar tīklu</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Pieprasīt maksājumus (izveido QR kodu un bitcoin: URIs)</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Komandrindas iespējas</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 aizmugurē</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Transakcijas pēc šī vel nebūs redzamas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Kļūda</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Brīdinājums</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informācija</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Sinhronizēts</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Atvērt maku</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Aizvērt maku</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Aizvērt visus makus</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Maka dati</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Atjaunot maku</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Maka nosaukums</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Logs</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 klients</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Kļūda: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Brīdinājums: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Datums: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Maks: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Adrese: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Transakcija nosūtīta</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Ienākoša transakcija</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Maciņš ir &lt;b&gt;šifrēts&lt;/b&gt; un pašlaik &lt;b&gt;atslēgts&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Maciņš ir &lt;b&gt;šifrēts&lt;/b&gt; un pašlaik &lt;b&gt;slēgts&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Daudzums:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Daudzums:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Maksa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Pēc Maksas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Atlikums:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">iezīmēt visus</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Koka režīms</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Saraksta režīms</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Daudzums</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datums</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Apstiprinājumi</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Apstiprināts</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Izveidot maku</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Atvērt maku</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Atjaunot maku</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Aizvērt maku</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Aizvērt visus makus</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Izveidot maku</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Maka nosaukums</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Maciņš</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Šifrēt maku</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Izveidot</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Mainīt adrese</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Nosaukums</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Adrese</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Tiks izveidota jauna datu mape.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">vārds</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Šāds ceļš jau pastāv un tā nav mape.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Šeit nevar izveidot datu mapi.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">versija</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Komandrindas iespējas</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">Neizslēdziet datoru kamēr šis logs nepazūd.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Sveiciens</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation type="unfinished">Izmantot noklusēto datu mapi</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation type="unfinished">Izmantot pielāgotu datu mapi:</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Kļūda</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Forma</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Pēdējā bloka laiks</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">ielīmēt adresi no starpliktuves</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Iespējas</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Galvenais</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">&amp;Datubāzes kešatmiņas izmērs</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation type="unfinished">Skriptu &amp;pārbaudes pavedienu skaits</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">Starpniekservera IP adrese (piem. IPv4: 127.0.0.1 / IPv6: ::1)</translation>
    </message>
    <message>
        <source>Minimize instead of exit the application when the window is closed. When this option is enabled, the application will be closed only after selecting Exit in the menu.</source>
        <translation type="unfinished">Minimizēt nevis aizvērt aplikāciju, kad logs tiek aizvērts. Kad šī iespēja ir ieslēgta, aplikācija tiks aizvērta, izvēloties Aizvērt izvēlnē.</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Atiestatīt visus klienta iestatījumus uz noklusējumu.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Atiestatīt Iestatījumus.</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Tīkls</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;Maciņš</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Eksperts</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">Ieslēgt bitcoin &amp;kontroles funkcijas</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation type="unfinished">&amp;Tērēt neapstiprinātu atlikumu</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">Starpniekservera &amp;IP:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;Ports:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Starpniekservera ports (piem. 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Logs</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation type="unfinished">Pēc loga minimizācijas rādīt tikai ikonu sistēmas teknē.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation type="unfinished">&amp;Minimizēt uz sistēmas tekni, nevis rīkjoslu</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation type="unfinished">M&amp;inimizēt aizverot</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;Izskats</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">Lietotāja interfeiss un &amp;valoda:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation type="unfinished">&amp;Vienības, kurās attēlot daudzumus:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation type="unfinished">Izvēlēties dalījuma vienību pēc noklusēšanas, ko izmantot interfeisā un nosūtot bitkoinus.</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation type="unfinished">Vai rādīt Bitcoin kontroles funkcijas vai nē.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;Labi</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Atcelt</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">pēc noklusēšanas</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">neviena</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">Apstiprināt iestatījumu atiestatīšanu</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <extracomment>Window title text of pop-up box that allows opening up of configuration file.</extracomment>
        <translation type="unfinished">Konfigurāciju Opcijas</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Turpināt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atcelt</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Kļūda</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation type="unfinished">Norādītā starpniekservera adrese nav derīga.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Forma</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation type="unfinished">Attēlotā informācija var būt novecojusi. Jūsu maciņš pēc savienojuma izveides automātiski sinhronizējas ar Bitcoin tīklu, taču šis process vēl nav beidzies.</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation type="unfinished">Pieejams:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation type="unfinished">Tava pašreizējā tērējamā bilance</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation type="unfinished">Neizšķirts:</translation>
    </message>
    <message>
        <source>Total of transactions that have yet to be confirmed, and do not yet count toward the spendable balance</source>
        <translation type="unfinished">Kopējā apstiprināmo transakciju vērtība, vēl nav ieskaitīta tērējamajā bilancē</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation type="unfinished">Nenobriedušu:</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation type="unfinished">Kopsumma:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation type="unfinished">Jūsu kopējā tekošā bilance</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">Nesenās transakcijas</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Copy to Clipboard</source>
        <translation type="unfinished">Nokopēt</translation>
    </message>
    <message>
        <source>Save…</source>
        <translation type="unfinished">Saglabāt...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Aiztaisīt</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">vai</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Received</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have received from the peer.</extracomment>
        <translation type="unfinished">Saņemts</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Adrese</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Tīkls</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>PNG Image</source>
        <extracomment>Expanded name of the PNG file format. See: https://en.wikipedia.org/wiki/Portable_Network_Graphics.</extracomment>
        <translation type="unfinished">PNG attēls</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation type="unfinished">Klienta versija</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informācija</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Vispārējs</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation type="unfinished">Sākuma laiks</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Tīkls</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Vārds</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Savienojumu skaits</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation type="unfinished">Bloku virkne</translation>
    </message>
    <message>
        <source>Received</source>
        <translation type="unfinished">Saņemts</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Versija</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Pēdējā bloka laiks</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Atvērt</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation type="unfinished">&amp;Konsole</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation type="unfinished">&amp;Tīkla Satiksme</translation>
    </message>
    <message>
        <source>Totals</source>
        <translation type="unfinished">Kopsummas</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation type="unfinished">Atkļūdošanas žurnāla datne</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation type="unfinished">Notīrīt konsoli</translation>
    </message>
    <message>
        <source>In:</source>
        <translation type="unfinished">Ie.:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation type="unfinished">Iz.:</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Jā</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Nē</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">No</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Daudzums:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Nosaukums:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;Ziņojums:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation type="unfinished">Notīrīt visus laukus formā.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Notīrīt</translation>
    </message>
    <message>
        <source>Requested payments history</source>
        <translation type="unfinished">Pieprasīto maksājumu vēsture</translation>
    </message>
    <message>
        <source>Show the selected request (does the same as double clicking an entry)</source>
        <translation type="unfinished">Parādīt atlasītos pieprasījumus (tas pats, kas dubultklikšķis uz ieraksta)</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Rādīt</translation>
    </message>
    <message>
        <source>Remove the selected entries from the list</source>
        <translation type="unfinished">Noņemt atlasītos ierakstus no saraksta.</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Noņemt</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation type="unfinished">Kopēt &amp;URI</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Daudzums:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Ziņojums:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Maciņš:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation type="unfinished">Kopēt &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">Kopēt &amp;Adresi</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datums</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nosaukums</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Ziņojums</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Sūtīt Bitkoinus</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation type="unfinished">Bitcoin Kontroles Funkcijas</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation type="unfinished">automātiski atlasīts</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation type="unfinished">Nepietiekami līdzekļi!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Daudzums:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Daudzums:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Maksa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Pēc Maksas:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Atlikums:</translation>
    </message>
    <message>
        <source>Custom change address</source>
        <translation type="unfinished">Pielāgota atlikuma adrese</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation type="unfinished">Transakcijas maksa:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Sūtīt vairākiem saņēmējiem uzreiz</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation type="unfinished">&amp;Pievienot Saņēmēju</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation type="unfinished">Notīrīt visus laukus formā.</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">&amp;Notīrīt visu</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Bilance:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Apstiprināt nosūtīšanu</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">&amp;Sūtīt</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">vai</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation type="unfinished">Transakcijas maksa</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(bez nosaukuma)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">Apjo&amp;ms</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation type="unfinished">&amp;Saņēmējs:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Nosaukums:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Izvēlies iepriekš izmantoto adresi</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">ielīmēt adresi no starpliktuves</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation type="unfinished">Noņem šo ierakstu</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Ziņojums:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation type="unfinished">Paraksti - Parakstīt / Pabaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation type="unfinished">Parakstīt &amp;Ziņojumu</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Izvēlies iepriekš izmantoto adresi</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">ielīmēt adresi no starpliktuves</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation type="unfinished">Šeit ievadi ziņojumu kuru vēlies parakstīt</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished">Paraksts</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation type="unfinished">Parakstīt ziņojumu lai pierādītu, ka esi šīs Bitcoin adreses īpašnieks.</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation type="unfinished">Parakstīt &amp;Ziņojumu</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation type="unfinished">Atiestatīt visus laukus</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">&amp;Notīrīt visu</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation type="unfinished">&amp;Pārbaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">&amp;Pārbaudīt Ziņojumu</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation type="unfinished">Atiestatīt visus laukus</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datums</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">No</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">nav zināms</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation type="unfinished">Transakcijas maksa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Ziņojums</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Daudzums</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation type="unfinished">Šis panelis parāda transakcijas detaļas</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datums</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nosaukums</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(bez nosaukuma)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>This week</source>
        <translation type="unfinished">Šonedēļ</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Šomēnes</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Šogad</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Apstiprināts</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Datums</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Nosaukums</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adrese</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Eksportēšana Neizdevās</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Izveidot jaunu maciņu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Kļūda</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Sūtīt Bitkoinus</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Eksportēt</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Datus no tekošā ieliktņa eksportēt uz failu</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Maka dati</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atcelt</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Ielāde pabeigta</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation type="unfinished">Kļūda ielādējot bloku datubāzi</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">Nepietiek bitkoinu</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation type="unfinished">Transakcijas parakstīšana neizdevās</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">Transakcijas summa ir pārāk maza</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">Transakcija ir pārāk liela</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation type="unfinished">-onlynet komandā norādīts nepazīstams tīkls: '%s'</translation>
    </message>
    </context>
</TS>